@@ -57,7 +57,7 @@ bool StyleConfigDialog::isDecoDirty() const
 
 void StyleConfigDialog::setDecoDirty()
 {
-   m_decoDirty = TRUE;
+   m_decoDirty = true;
 }
 
 #include <styleconfdialog.moc>
