@@ -208,7 +208,7 @@ bool Applet::eventFilter(TQObject *o, TQEvent *ev)
         {
 //             windowIndicator->activateItemAt ( -1 );
             windowList->close();
-            return FALSE;
+            return false;
         }
         else
 // #endif
@@ -221,22 +221,22 @@ bool Applet::eventFilter(TQObject *o, TQEvent *ev)
             {
                 if (w->backgroundOrigin() != TQWidget::WidgetOrigin)
                 {
-                    w->blockSignals(TRUE); // to avoid loops
+                    w->blockSignals(true); // to avoid loops
                     w->setBackgroundOrigin(TQWidget::WidgetOrigin);
-                    w->blockSignals(FALSE);
+                    w->blockSignals(false);
                 }
             }
 // #if 0
             else if (w->backgroundOrigin() != TQWidget::ParentOrigin)
             {
-                w->blockSignals(TRUE);
+                w->blockSignals(true);
                 w->setBackgroundOrigin(TQWidget::ParentOrigin);
-                w->blockSignals(FALSE);
+                w->blockSignals(false);
             }
-            return FALSE;
+            return false;
         }
 #endif
-        return FALSE;
+        return false;
     }
 
 void Applet::windowAdded( WId w_P )
@@ -269,7 +269,7 @@ void Applet::windowAdded( WId w_P )
                goto titlejump; // mainly for scummvm apps - jumps to netwm caption parsing
             XFree( classHint.res_name );
             XFree( classHint.res_class );
-            int i = title.findRev( name, -1, FALSE );
+            int i = title.findRev( name, -1, false );
             if (i > -1)
             {
                int j = title.find(' ',i);
@@ -671,7 +671,7 @@ void MenuEmbed::sendSyntheticConfigureNotifyEvent()
         c.border_width = 0;
         c.above = None;
         c.override_redirect = 0;
-        XSendEvent( tqt_xdisplay(), c.event, TRUE, StructureNotifyMask, (XEvent*)&c );
+        XSendEvent( tqt_xdisplay(), c.event, true, StructureNotifyMask, (XEvent*)&c );
     }
 }
 
