@@ -1,5 +1,5 @@
 
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tqsplitter.h>
 #include <kiconloader.h>
 #include <stdlib.h>
